@@ -58,6 +58,7 @@ int Q_DECL_EXPORT kdemain(int argc, char **argv);
 
 #include <KLocalizedString>
 #include <KMacroExpander>
+#include <QRegularExpression>
 
 // CDDB
 #include <KCDDB/Client>
@@ -67,13 +68,11 @@ int Q_DECL_EXPORT kdemain(int argc, char **argv);
 class KIOPluginForMetaData : public QObject
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.audiocd" FILE "audiocd.json")
+    Q_PLUGIN_METADATA(IID "org.kde.kio.worker.audiocd" FILE "audiocd.json")
 };
 
 using namespace KIO;
 
-#define CDDB_INFORMATION I18N_NOOP("CDDB Information")
-
 using namespace AudioCD;
 
 extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
@@ -93,8 +92,8 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 
     qCDebug(AUDIOCD_KIO_LOG) << "Starting " << getpid();
 
-    AudioCDProtocol slave(argv[1], argv[2], argv[3]);
-    slave.dispatchLoop();
+    AudioCDProtocol worker(argv[1], argv[2], argv[3]);
+    worker.dispatchLoop();
 
     qCDebug(AUDIOCD_KIO_LOG) << "Done";
 
@@ -104,7 +103,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 enum Which_dir {
     Unknown = 0, // Error
     Info, // CDDB info
-    Base, // The ioslave base directory showing all drives
+    Base, // The KIO worker base directory showing all drives
     Root, // The root directory, shows all these :)
     FullCD, // Show a single file containing all of the data
     EncoderDir, // The root directory created by an encoder
@@ -193,7 +192,7 @@ public:
 int paranoia_read_limited_error;
 
 AudioCDProtocol::AudioCDProtocol(const QByteArray &protocol, const QByteArray &pool, const QByteArray &app)
-    : SlaveBase(protocol, pool, app)
+    : WorkerBase(protocol, pool, app)
 {
     d = new Private;
     // Add encoders
@@ -266,7 +265,7 @@ static void setDeviceToCd(KCompactDisc *cd, struct cdrom_drive *drive)
     }
 #else
 #ifdef __GNUC__
-#warning audiocd ioslave is not going to work for you
+#warning audiocd KIO worker is not going to work for you
 #endif
 #endif
 }
@@ -274,23 +273,23 @@ static void setDeviceToCd(KCompactDisc *cd, struct cdrom_drive *drive)
 // Initiate a request to access the CD drive.  If there is no valid drive
 // specified or there is a problem, then error() must be (or have been)
 // called before returning a null pointer.
-struct cdrom_drive *AudioCDProtocol::initRequest(const QUrl &url)
+KIO::WorkerResult AudioCDProtocol::initRequest(const QUrl &url, struct cdrom_drive **drive)
 {
     // Load our Settings.
     loadSettings();
     // Then URL parameters can overrule our settings.
     parseURLArgs(url);
 
-    struct cdrom_drive *drive = getDrive();
-    if (drive == nullptr) {
-        return nullptr;
+    const KIO::WorkerResult result = getDrive(drive);
+    if (!result.success()) {
+        return result;
     }
 
-    if (d->tocsAreDifferent(drive)) {
+    if (d->tocsAreDifferent(*drive)) {
         // Update our knowledge of the disc
         KCompactDisc cd(KCompactDisc::Asynchronous);
-        setDeviceToCd(&cd, drive);
-        d->setToc(drive);
+        setDeviceToCd(&cd, *drive);
+        d->setToc(*drive);
         d->tracks = cd.tracks();
         for (uint i = 0; i < cd.tracks(); i++)
             d->trackIsAudio[i] = cd.isAudio(i + 1);
@@ -426,7 +425,7 @@ struct cdrom_drive *AudioCDProtocol::initRequest(const QUrl &url)
 
     qCDebug(AUDIOCD_KIO_LOG) << "path=" << path << " file=" << d->fname << " req_track=" << d->req_track << " which_dir=" << d->which_dir
                              << " full CD?=" << d->req_allTracks;
-    return drive;
+    return KIO::WorkerResult::pass();
 }
 
 bool AudioCDProtocol::getSectorsForRequest(struct cdrom_drive *drive, long &firstSector, long &lastSector) const
@@ -446,11 +445,11 @@ bool AudioCDProtocol::getSectorsForRequest(struct cdrom_drive *drive, long &firs
 }
 
 static uint findInformationFileNumber(const QString &filename, uint max) {
-    if (filename == QStringLiteral("%1.txt").arg(i18n(CDDB_INFORMATION)))
+    if (filename == QStringLiteral("%1.txt").arg(i18n("CDDB Information")))
         return 1;
 
     for (uint i = 2; i <= max; ++i) {
-        if (filename == QStringLiteral("%1_%2.txt").arg(i18n(CDDB_INFORMATION)).arg(i)) {
+        if (filename == QStringLiteral("%1_%2.txt").arg(i18n("CDDB Information")).arg(i)) {
             return i;
         }
     }
@@ -458,14 +457,13 @@ static uint findInformationFileNumber(const QString &filename, uint max) {
     return max + 1;
 }
 
-// See whether this is the root of the ioslave (listing of all
+// See whether this is the root of the io worker (listing of all
 // available CD drives) or the root of a drive (listing of encoder
 // subdirectories and track WAV files).
 //
 // This needs to be deduced from the URL without calling initRequest()
-// or getDrive(), either of which may call error().  It is not an
-// error if there is no drive to be accessed and none needs to be, but
-// subsequently calling finished() will assert.
+// or getDrive(), either of which may return KIO::WorkerResult::fail().  It is not an
+// error if there is no drive to be accessed and none needs to be.
 //
 // So parse the URL only.  Either Base, Root or Unknown (meaning "anywhere
 // else") will be returned.
@@ -473,7 +471,7 @@ static Which_dir whichFromUrl(const QUrl &url)
 {
     QUrlQuery query(url);
     if (!query.hasQueryItem(QStringLiteral("device"))) { // see if "device" query present
-        return Base; // if not, must be slave base
+        return Base; // if not, must be KIO worker base
     }
 
     if (url.path() == QLatin1String("/")) { // see if the device root
@@ -486,16 +484,15 @@ static Which_dir whichFromUrl(const QUrl &url)
 // Check that the URL does not have a host specified, and return an error
 // if it does.  Moved here because not all operations need to or should
 // call initRequest().
-bool AudioCDProtocol::checkNoHost(const QUrl &url)
+KIO::WorkerResult AudioCDProtocol::checkNoHost(const QUrl &url)
 {
     if (!url.host().isEmpty()) {
-        error(KIO::ERR_UNSUPPORTED_ACTION,
-              i18n("You cannot specify a host with this protocol. "
-                   "Please use the audiocd:/ format instead."));
-        return false;
+        return KIO::WorkerResult::fail(KIO::ERR_UNSUPPORTED_ACTION,
+                                       i18n("You cannot specify a host with this protocol. "
+                                            "Please use the audiocd:/ format instead."));
     }
 
-    return true;
+    return KIO::WorkerResult::pass();
 }
 
 // Escape any '/'es in what should be a file name.
@@ -507,19 +504,20 @@ static QString escapePath(const QString &in)
     return result;
 }
 
-void AudioCDProtocol::get(const QUrl &url)
+KIO::WorkerResult AudioCDProtocol::get(const QUrl &url)
 {
-    if (!checkNoHost(url)) {
-        return;
+    const KIO::WorkerResult noHostResult = checkNoHost(url);
+    if (!noHostResult.success()) {
+        return noHostResult;
     }
 
-    struct cdrom_drive *drive = initRequest(url);
-    if (drive == nullptr) {
-        // Do not call error(), getDrive() will already have done that.
-        return;
+    struct cdrom_drive *drive;
+    const KIO::WorkerResult initResult = initRequest(url, &drive);
+    if (!initResult.success()) {
+        return initResult;
     }
 
-    if (d->fname.contains(i18n(CDDB_INFORMATION))) {
+    if (d->fname.contains(i18n("CDDB Information"))) {
         const uint choice = findInformationFileNumber(d->fname, d->cddbList.count());
         uint count = 1;
         CDInfoList::iterator it;
@@ -531,39 +529,35 @@ void AudioCDProtocol::get(const QUrl &url)
                 data((*it).toString().toUtf8());
                 // send an empty QByteArray to signal end of data.
                 data(QByteArray());
-                finished();
                 found = true;
                 break;
             }
             count++;
         }
-        if (!found && d->fname.contains(i18n(CDDB_INFORMATION) + QLatin1Char(':'))) {
+        if (!found && d->fname.contains(i18n("CDDB Information") + QLatin1Char(':'))) {
             // FIXME: should be "text/plain"?
             mimeType(QStringLiteral("text/html"));
             // data(QCString( d->fname.latin1() ));
             // send an empty QByteArray to signal end of data.
             data(QByteArray());
-            finished();
             found = true;
         }
-        if (!found)
-            error(KIO::ERR_DOES_NOT_EXIST, url.path());
         cdda_close(drive);
-        return;
+        if (!found)
+            return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.path());
+        return KIO::WorkerResult::pass();
     }
 
     long firstSector, lastSector;
     if (!getSectorsForRequest(drive, firstSector, lastSector)) {
-        error(KIO::ERR_DOES_NOT_EXIST, url.path());
         cdda_close(drive);
-        return;
+        return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.path());
     }
 
     AudioCDEncoder *encoder = determineEncoder(d->fname);
     if (!encoder) {
-        error(KIO::ERR_DOES_NOT_EXIST, url.path());
         cdda_close(drive);
-        return;
+        return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.path());
     }
 
     KCDDB::CDInfo info;
@@ -589,14 +583,14 @@ void AudioCDProtocol::get(const QUrl &url)
     mimeType(QLatin1String(encoder->mimeType()));
 
     // Read data (track/disk) from the cd
-    paranoiaRead(drive, firstSector, lastSector, encoder, url.fileName(), size);
+    const KIO::WorkerResult readResult = paranoiaRead(drive, firstSector, lastSector, encoder, url.fileName(), size);
 
     // send an empty QByteArray to signal end of data.
     data(QByteArray());
 
     cdda_close(drive);
 
-    finished();
+    return readResult;
 }
 
 static void app_dir(UDSEntry &e, const QString &n, size_t s)
@@ -631,10 +625,11 @@ static void app_file(UDSEntry &e, const QString &n, size_t s, const QString &mim
         e.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, mimetype);
 }
 
-void AudioCDProtocol::stat(const QUrl &url)
+KIO::WorkerResult AudioCDProtocol::stat(const QUrl &url)
 {
-    if (!checkNoHost(url)) {
-        return;
+    const KIO::WorkerResult result = checkNoHost(url);
+    if (!result.success()) {
+        return result;
     }
 
     if (whichFromUrl(url) == Base) {
@@ -646,14 +641,13 @@ void AudioCDProtocol::stat(const QUrl &url)
         const QStringList &deviceNames = KCompactDisc::cdromDeviceNames();
         app_dir(entry, escapePath(QStringLiteral("/")), deviceNames.count());
         statEntry(entry);
-        finished();
-        return;
+        return KIO::WorkerResult::pass();
     }
 
-    struct cdrom_drive *drive = initRequest(url);
-    if (drive == nullptr) {
-        // Do not call error(), getDrive() will already have done that.
-        return;
+    struct cdrom_drive *drive;
+    const KIO::WorkerResult initResult = initRequest(url, &drive);
+    if (!initResult.success()) {
+        return initResult;
     }
 
     if (d->which_dir == Info) {
@@ -663,9 +657,9 @@ void AudioCDProtocol::stat(const QUrl &url)
             UDSEntry entry;
             app_dir(entry, escapePath(url.fileName()), d->cddbList.count());
             statEntry(entry);
-            finished();
-            return;
-        } else if (d->fname.contains(i18n(CDDB_INFORMATION))) {
+            return KIO::WorkerResult::pass();
+        }
+        if (d->fname.contains(i18n("CDDB Information"))) {
             // choice is 1-indexed so we need <= and -1 when accessing d->cddbList
             const uint choice = findInformationFileNumber(d->fname, d->cddbList.count());
             if (choice <= (uint)d->cddbList.count()) {
@@ -673,8 +667,7 @@ void AudioCDProtocol::stat(const QUrl &url)
                 UDSEntry entry;
                 app_file(entry, escapePath(url.fileName()), d->cddbList.at(choice - 1).toString().toLatin1().size(), QStringLiteral("text/plain"));
                 statEntry(entry);
-                finished();
-                return;
+                return KIO::WorkerResult::pass();
             }
         }
     }
@@ -688,9 +681,8 @@ void AudioCDProtocol::stat(const QUrl &url)
     if (!d->req_allTracks) { // we only want to rip one track.
         // does this track exist?
         if (isFile && (trackNumber < 1 || trackNumber > d->tracks)) {
-            error(KIO::ERR_DOES_NOT_EXIST, url.path());
             cdda_close(drive);
-            return;
+            return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.path());
         }
     }
 
@@ -706,13 +698,14 @@ void AudioCDProtocol::stat(const QUrl &url)
 
     statEntry(entry);
     cdda_close(drive);
-    finished();
+    return KIO::WorkerResult::pass();
 }
 
-void AudioCDProtocol::listDir(const QUrl &url)
+KIO::WorkerResult AudioCDProtocol::listDir(const QUrl &url)
 {
-    if (!checkNoHost(url)) {
-        return;
+    const KIO::WorkerResult result = checkNoHost(url);
+    if (!result.success()) {
+        return result;
     }
 
     UDSEntry entry;
@@ -736,28 +729,23 @@ void AudioCDProtocol::listDir(const QUrl &url)
             listEntry(entry);
         }
         totalSize(entry.count());
-        finished();
-        return;
+        return KIO::WorkerResult::pass();
     }
 
-    struct cdrom_drive *drive = initRequest(url);
-
-    // Some error checking before proceeding
-    if (drive == nullptr) {
-        // Do not call error(), getDrive() will already have done that.
-        return;
+    struct cdrom_drive *drive;
+    const KIO::WorkerResult initResult = initRequest(url, &drive);
+    if (!initResult.success()) {
+        return initResult;
     }
 
     if (d->which_dir == Unknown) {
-        error(KIO::ERR_DOES_NOT_EXIST, url.path());
         cdda_close(drive);
-        return;
+        return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, url.path());
     }
 
     if (!d->fname.isEmpty()) {
-        error(KIO::ERR_IS_FILE, url.path());
         cdda_close(drive);
-        return;
+        return KIO::WorkerResult::fail(KIO::ERR_IS_FILE, url.path());
     }
 
     // Generate templated names every time
@@ -770,15 +758,15 @@ void AudioCDProtocol::listDir(const QUrl &url)
         for (it = d->cddbList.begin(); it != d->cddbList.end(); ++it) {
             (*it).toString();
             if (count == 1)
-                app_file(entry, QString::fromLatin1("%1.txt").arg(i18n(CDDB_INFORMATION)), ((*it).toString().length()) + 1);
+                app_file(entry, QString::fromLatin1("%1.txt").arg(i18n("CDDB Information")), ((*it).toString().length()) + 1);
             else
-                app_file(entry, QString::fromLatin1("%1_%2.txt").arg(i18n(CDDB_INFORMATION)).arg(count), ((*it).toString().length()) + 1);
+                app_file(entry, QString::fromLatin1("%1_%2.txt").arg(i18n("CDDB Information")).arg(count), ((*it).toString().length()) + 1);
             count++;
             listEntry(entry);
         }
         // Error
         if (count == 1) {
-            app_file(entry, QString::fromLatin1("%1: %2.txt").arg(i18n(CDDB_INFORMATION)).arg(KCDDB::resultToString(d->cddbResult)), 0);
+            app_file(entry, QString::fromLatin1("%1: %2.txt").arg(i18n("CDDB Information")).arg(KCDDB::resultToString(d->cddbResult)), 0);
             count++;
             listEntry(entry);
         }
@@ -835,9 +823,8 @@ void AudioCDProtocol::listDir(const QUrl &url)
                 case Info:
                 case Unknown:
                 default:
-                    error(KIO::ERR_INTERNAL, url.path());
                     cdda_close(drive);
-                    return;
+                    return KIO::WorkerResult::fail(KIO::ERR_INTERNAL, url.path());
                 }
             }
         } else {
@@ -848,7 +835,7 @@ void AudioCDProtocol::listDir(const QUrl &url)
 
     totalSize(entry.count());
     cdda_close(drive);
-    finished();
+    return KIO::WorkerResult::pass();
 }
 
 void AudioCDProtocol::addEntry(const QString &trackTitle, AudioCDEncoder *encoder, struct cdrom_drive *drive, int trackNo)
@@ -880,70 +867,66 @@ long AudioCDProtocol::fileSize(long firstSector, long lastSector, AudioCDEncoder
     return encoder->size(length_seconds);
 }
 
-// If a null pointer (meaning no or an invalid drive) is to be returned,
-// this must call error() first and the caller must not subsequently
-// call error() or finished().
-struct cdrom_drive *AudioCDProtocol::getDrive()
+KIO::WorkerResult AudioCDProtocol::getDrive(struct cdrom_drive **drive)
 {
     const QByteArray device(QFile::encodeName(d->device));
     if (device.isEmpty()) {
-        error(KIO::ERR_MALFORMED_URL, i18nc("The URL does not include a device name", "Missing device specification"));
-        return nullptr;
+        *drive = nullptr;
+        return KIO::WorkerResult::fail(KIO::ERR_MALFORMED_URL, i18nc("The URL does not include a device name", "Missing device specification"));
     }
 
-    struct cdrom_drive *drive = cdda_identify(device.data(), CDDA_MESSAGE_FORGETIT, nullptr);
-    if (drive == nullptr) {
+    *drive = cdda_identify(device.data(), CDDA_MESSAGE_FORGETIT, nullptr);
+    if (*drive == nullptr) {
         qCDebug(AUDIOCD_KIO_LOG) << "Can't find an audio CD on: \"" << d->device << "\"";
 
         const QFileInfo fi(d->device);
         if (!fi.isReadable())
-            error(KIO::ERR_SLAVE_DEFINED,
-                  i18n("Device does not have read permissions for this account.  "
-                       "Check the read permissions on the device."));
-        else if (!fi.isWritable())
-            error(KIO::ERR_SLAVE_DEFINED,
-                  i18n("Device does not have write permissions for this account.  "
-                       "Check the write permissions on the device."));
-        else if (!fi.exists())
-            error(KIO::ERR_DOES_NOT_EXIST, d->device);
-        else
-            error(KIO::ERR_SLAVE_DEFINED,
-                  i18n("Unknown error.  If you have a cd in the drive try running "
-                       "cdparanoia -vsQ as yourself (not root). Do you see a track "
-                       "list? If not, make sure you have permission to access the CD "
-                       "device. If you are using SCSI emulation (possible if you "
-                       "have an IDE CD writer) then make sure you check that you "
-                       "have read and write permissions on the generic SCSI device, "
-                       "which is probably /dev/sg0, /dev/sg1, etc.. If it still does "
-                       "not work, try typing audiocd:/?device=/dev/sg0 (or similar) "
-                       "to tell kio_audiocd which device your CD-ROM is."));
-        return nullptr;
+            return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED,
+                                           i18n("Device does not have read permissions for this account.  "
+                                                "Check the read permissions on the device."));
+        if (!fi.isWritable())
+            return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED,
+                                           i18n("Device does not have write permissions for this account.  "
+                                                "Check the write permissions on the device."));
+        if (!fi.exists())
+            return KIO::WorkerResult::fail(KIO::ERR_DOES_NOT_EXIST, d->device);
+
+        return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED,
+                                       i18n("Unknown error.  If you have a cd in the drive try running "
+                                            "cdparanoia -vsQ as yourself (not root). Do you see a track "
+                                            "list? If not, make sure you have permission to access the CD "
+                                            "device. If you are using SCSI emulation (possible if you "
+                                            "have an IDE CD writer) then make sure you check that you "
+                                            "have read and write permissions on the generic SCSI device, "
+                                            "which is probably /dev/sg0, /dev/sg1, etc.. If it still does "
+                                            "not work, try typing audiocd:/?device=/dev/sg0 (or similar) "
+                                            "to tell kio_audiocd which device your CD-ROM is."));
     }
 
-    if (cdda_open(drive) != 0) {
+    if (cdda_open(*drive) != 0) {
         qCDebug(AUDIOCD_KIO_LOG) << "cdda_open failed";
-        error(KIO::ERR_CANNOT_OPEN_FOR_READING, d->device);
-        cdda_close(drive);
-        return nullptr;
+        cdda_close(*drive);
+        *drive = nullptr;
+        return KIO::WorkerResult::fail(KIO::ERR_CANNOT_OPEN_FOR_READING, d->device);
     }
 
-    return drive;
+    return KIO::WorkerResult::pass();
 }
 
-void AudioCDProtocol::paranoiaRead(struct cdrom_drive *drive,
-                                   long firstSector,
-                                   long lastSector,
-                                   AudioCDEncoder *encoder,
-                                   const QString &fileName,
-                                   unsigned long size)
+KIO::WorkerResult AudioCDProtocol::paranoiaRead(struct cdrom_drive *drive,
+                                                long firstSector,
+                                                long lastSector,
+                                                AudioCDEncoder *encoder,
+                                                const QString &fileName,
+                                                unsigned long size)
 {
     if (!encoder || !drive)
-        return;
+        return KIO::WorkerResult::fail();
 
     cdrom_paranoia *paranoia = paranoia_init(drive);
     if (nullptr == paranoia) {
         qCDebug(AUDIOCD_KIO_LOG) << "paranoia_init failed";
-        return;
+        return KIO::WorkerResult::fail();
     }
 
     int paranoiaLevel = PARANOIA_MODE_FULL ^ PARANOIA_MODE_NEVERSKIP;
@@ -975,6 +958,7 @@ void AudioCDProtocol::paranoiaRead(struct cdrom_drive *drive,
     // TODO test for errors (processed<0)?
     processedSize(processed);
     bool ok = true;
+    QString errorString;
 
     unsigned long lastSize = size;
     unsigned long diff = 0;
@@ -993,7 +977,7 @@ void AudioCDProtocol::paranoiaRead(struct cdrom_drive *drive,
         if (nullptr == buf) {
             qCDebug(AUDIOCD_KIO_LOG) << "Unrecoverable error in paranoia_read";
             ok = false;
-            error(ERR_SLAVE_DEFINED, i18n("Error reading audio data for %1 from the CD", fileName));
+            errorString = i18n("Error reading audio data for %1 from the CD", fileName);
             break;
         }
 
@@ -1003,11 +987,10 @@ void AudioCDProtocol::paranoiaRead(struct cdrom_drive *drive,
         if (encoderProcessed == -1) {
             qCDebug(AUDIOCD_KIO_LOG) << "Encoder processing error, stopping.";
             ok = false;
-            QString errMsg = i18n("Could not read %1: encoding failed", fileName);
+            errorString = i18n("Could not read %1: encoding failed", fileName);
             const QString details = encoder->lastErrorMessage();
             if (!details.isEmpty())
-                errMsg += QLatin1Char('\n') + details;
-            error(ERR_SLAVE_DEFINED, errMsg);
+                errorString += QLatin1Char('\n') + details;
             break;
         }
         processed += encoderProcessed;
@@ -1082,10 +1065,16 @@ void AudioCDProtocol::paranoiaRead(struct cdrom_drive *drive,
             totalSize(processed);
         processedSize(processed);
     } else if (ok) // i.e. no error message already emitted
-        error(ERR_SLAVE_DEFINED, i18n("Could not read %1: encoding failed", fileName));
+        errorString = i18n("Could not read %1: encoding failed", fileName);
 
     paranoia_free(paranoia);
     paranoia = nullptr;
+
+    if (!errorString.isEmpty()) {
+        return KIO::WorkerResult::fail(ERR_WORKER_DEFINED, errorString);
+    }
+
+    return KIO::WorkerResult::pass();
 }
 
 /**
@@ -1230,7 +1219,7 @@ void AudioCDProtocol::generateTemplateTitles()
         macros[QStringLiteral("year")] = info.get(Year).toString();
 
         QString title = escapePath(KMacroExpander::expandMacros(d->fileNameTemplate, macros, QLatin1Char('%')));
-        title.replace(QRegExp(d->rsearch), d->rreplace);
+        title.replace(QRegularExpression(d->rsearch), d->rreplace);
         d->templateTitles.append(title);
     }
 
@@ -1240,7 +1229,7 @@ void AudioCDProtocol::generateTemplateTitles()
     macros[QStringLiteral("genre")] = info.get(Genre).toString();
     macros[QStringLiteral("year")] = info.get(Year).toString();
     d->templateAlbumName = escapePath(KMacroExpander::expandMacros(d->albumNameTemplate, macros, QLatin1Char('%')));
-    d->templateAlbumName.replace(QRegExp(d->rsearch), d->rreplace);
+    d->templateAlbumName.replace(QRegularExpression(d->rsearch), d->rreplace);
 
     d->templateFileLocation = KMacroExpander::expandMacros(d->fileLocationTemplate, macros, QLatin1Char('%'));
 }
